@@ -44,6 +44,7 @@ struct ExistingFile
 {
 	typedef std::string value_type;
 	static std::string parse(const std::string& val);
+	static std::string toString(const value_type& val);
 };
 
 /// Interface for a parser for one commandline option
@@ -90,6 +91,7 @@ protected:
 	virtual bool parse(const std::string& param) = 0;
 
 public:
+	Option();
 	virtual ~Option() {}
 
 	const bool isSet() const { return m_isset; }
@@ -108,6 +110,9 @@ public:
 	std::string usage;
 	std::string description;
 
+	// Set to true if the option should not be documented
+	bool hidden;
+
 	friend class OptionGroup;
 	friend class Engine;
 };
@@ -177,6 +182,10 @@ protected:
 	}
 
 public:
+        void setValue( const typename T::value_type &a ) {
+            m_value = a;
+        }
+
 	typename T::value_type value() const { return m_value; }
 
 	// Deprecated
@@ -276,7 +285,7 @@ class OptionGroup : public Managed
 
 protected:
 	OptionGroup(MemoryManager* mman = 0, const std::string& description = std::string())
-		: m_manager(mman), description(description) {}
+		: m_manager(mman), description(description), hidden(false) {}
 
 public:
 	Option* add(Option* o) { options.push_back(o); return o; }
@@ -285,6 +294,9 @@ public:
 
 	std::string description;
 
+	// Set to true if the option group should not be documented
+	bool hidden;
+
 	/**
 	 * Create a new option
 	 */
